@@ -58,9 +58,9 @@ class DegenerateBTree(unittest.TestCase):
 
     def _build_degenerate_tree(self):
         # Build the buckets and chain them together.
+        from BTrees.check import check
         from BTrees.IIBTree import IISet
         from BTrees.IIBTree import IITreeSet
-        from BTrees.check import check
         bucket11 = IISet([11])
 
         bucket7 = IISet()
@@ -129,7 +129,7 @@ class DegenerateBTree(unittest.TestCase):
         sorted_keys.sort()
         self.assertEqual(list(tree.keys()), sorted_keys)
         for k in keys:
-            self.assertTrue(k in tree)
+            self.assertIn(k, tree)
         if keys:
             lokey = sorted_keys[0]
             hikey = sorted_keys[-1]
@@ -193,9 +193,9 @@ class DegenerateBTree(unittest.TestCase):
 LP294788_ids = {}
 
 
-class ToBeDeleted(object):
+class ToBeDeleted:
     def __init__(self, id):
-        assert isinstance(id, int) #we don't want to store any object ref here
+        assert isinstance(id, int)  # don't want to store any object ref here
         self.id = id
 
         global LP294788_ids
@@ -205,9 +205,6 @@ class ToBeDeleted(object):
         global LP294788_ids
         LP294788_ids.pop(self.id, None)
 
-    def __cmp__(self, other):
-        return cmp(self.id, other.id)
-
     def __le__(self, other):
         return self.id <= other.id
 
@@ -255,6 +252,7 @@ class TestBugFixes(unittest.TestCase):
         # To simulate real life, some random data is used to exercise the tree
         import gc
         import random
+
         from BTrees.OOBTree import OOBTree
 
         t = OOBTree()
@@ -268,7 +266,7 @@ class TestBugFixes(unittest.TestCase):
         ids = {}
         for i in range(1024):
             if trandom.random() > 0.1 or not ids:
-                #add
+                # add
                 id = None
                 while id is None or id in ids:
                     id = trandom.randint(0, 1000000)
@@ -276,7 +274,7 @@ class TestBugFixes(unittest.TestCase):
                 ids[id] = 1
                 t[id] = ToBeDeleted(id)
             else:
-                #del
+                # del
                 keys = list(ids.keys())
                 if keys:
                     id = trandom.choice(list(ids.keys()))
@@ -289,10 +287,10 @@ class TestBugFixes(unittest.TestCase):
             del t[id]
         ids = None
 
-        #to be on the safe side run a full GC
+        # to be on the safe side run a full GC
         gc.collect()
 
-        #print LP294788_ids
+        # print LP294788_ids
 
         self.assertEqual(len(t), 0)
         self.assertEqual(len(LP294788_ids), 0)
@@ -303,15 +301,15 @@ class TestBugFixes(unittest.TestCase):
         ids = {}
         for i in range(1024):
             if trandom.random() > 0.1 or not ids:
-                #add
+                # add
                 id = None
                 while id is None or id in ids:
                     id = trandom.randint(0, 1000000)
 
                 ids[id] = 1
-                t[id] = (id, ToBeDeleted(id), u'somename')
+                t[id] = (id, ToBeDeleted(id), 'somename')
             else:
-                #del
+                # del
                 keys = list(ids.keys())
                 if keys:
                     id = trandom.choice(keys)
@@ -324,23 +322,22 @@ class TestBugFixes(unittest.TestCase):
             del t[id]
         ids = None
 
-        #to be on the safe side run a full GC
+        # to be on the safe side run a full GC
         gc.collect()
 
-        #print LP294788_ids
+        # print LP294788_ids
 
         self.assertEqual(len(t), 0)
         self.assertEqual(len(LP294788_ids), 0)
         # \\\
 
-
         # /// BTree keys are objects, value is an int
         t = OOBTree()
         LP294788_ids = {}
         ids = {}
         for i in range(1024):
             if trandom.random() > 0.1 or not ids:
-                #add
+                # add
                 id = None
                 while id is None or id in ids:
                     id = ToBeDeleted(trandom.randint(0, 1000000))
@@ -348,7 +345,7 @@ class TestBugFixes(unittest.TestCase):
                 ids[id] = 1
                 t[id] = 1
             else:
-                #del
+                # del
                 id = trandom.choice(list(ids.keys()))
                 del ids[id]
                 del t[id]
@@ -357,13 +354,13 @@ class TestBugFixes(unittest.TestCase):
         trandom.shuffle(list(ids))
         for id in ids:
             del t[id]
-        #release all refs
+        # release all refs
         ids = id = None
 
-        #to be on the safe side run a full GC
+        # to be on the safe side run a full GC
         gc.collect()
 
-        #print LP294788_ids
+        # print LP294788_ids
 
         self.assertEqual(len(t), 0)
         self.assertEqual(len(LP294788_ids), 0)
@@ -374,16 +371,16 @@ class TestBugFixes(unittest.TestCase):
         ids = {}
         for i in range(1024):
             if trandom.random() > 0.1 or not ids:
-                #add
+                # add
                 id = None
                 while id is None or id in ids:
                     id = trandom.randint(0, 1000000)
-                    id = (id, ToBeDeleted(id), u'somename')
+                    id = (id, ToBeDeleted(id), 'somename')
 
                 ids[id] = 1
                 t[id] = 1
             else:
-                #del
+                # del
                 id = trandom.choice(list(ids.keys()))
                 del ids[id]
                 del t[id]
@@ -392,26 +389,28 @@ class TestBugFixes(unittest.TestCase):
         trandom.shuffle(list(ids))
         for id in ids:
             del t[id]
-        #release all refs
-        ids = id = key = None
+        # release all refs
+        ids = id = None
 
-        #to be on the safe side run a full GC
+        # to be on the safe side run a full GC
         gc.collect()
 
-        #print LP294788_ids
+        # print LP294788_ids
 
         self.assertEqual(len(t), 0)
         self.assertEqual(len(LP294788_ids), 0)
 
 
-# cmp error propagation tests
+# comparison error propagation tests
 
 
 class DoesntLikeBeingCompared:
 
-    def __cmp__(self, other):
+    def _cmp(self, other):
         raise ValueError('incomparable')
-    __lt__ = __le__ = __eq__ = __ne__ = __ge__ = __gt__ = __cmp__
+
+    __lt__ = __le__ = __eq__ = __ne__ = __ge__ = __gt__ = _cmp
+
 
 class TestCmpError(unittest.TestCase):
 
@@ -431,6 +430,7 @@ class TestCmpError(unittest.TestCase):
 class FamilyTest(unittest.TestCase):
     def test32(self):
         from zope.interface.verify import verifyObject
+
         import BTrees
         from BTrees.IOBTree import IOTreeSet
         verifyObject(BTrees.Interfaces.IBTreeFamily, BTrees.family32)
@@ -456,10 +456,10 @@ class FamilyTest(unittest.TestCase):
             BTrees.family32.OU, BTrees.OUBTree)
         s = IOTreeSet()
         s.insert(BTrees.family32.maxint)
-        self.assertTrue(BTrees.family32.maxint in s)
+        self.assertIn(BTrees.family32.maxint, s)
         s = IOTreeSet()
         s.insert(BTrees.family32.minint)
-        self.assertTrue(BTrees.family32.minint in s)
+        self.assertIn(BTrees.family32.minint, s)
         s = IOTreeSet()
         # this next bit illustrates an, um, "interesting feature".  If
         # the characteristics change to match the 64 bit version, please
@@ -473,6 +473,7 @@ class FamilyTest(unittest.TestCase):
 
     def test64(self):
         from zope.interface.verify import verifyObject
+
         import BTrees
         from BTrees.LOBTree import LOTreeSet
         verifyObject(BTrees.Interfaces.IBTreeFamily, BTrees.family64)
@@ -498,14 +499,19 @@ class FamilyTest(unittest.TestCase):
             BTrees.family64.OU, BTrees.OQBTree)
         s = LOTreeSet()
         s.insert(BTrees.family64.maxint)
-        self.assertTrue(BTrees.family64.maxint in s)
+        self.assertIn(BTrees.family64.maxint, s)
         s = LOTreeSet()
         s.insert(BTrees.family64.minint)
-        self.assertTrue(BTrees.family64.minint in s)
+        self.assertIn(BTrees.family64.minint, s)
         s = LOTreeSet()
+
         # XXX why oh why do we expect ValueError here, but TypeError in test32?
-        self.assertRaises((TypeError, OverflowError), s.insert, BTrees.family64.maxint + 1)
-        self.assertRaises((TypeError, OverflowError), s.insert, BTrees.family64.minint - 1)
+        with self.assertRaises((TypeError, OverflowError)):
+            s.insert(BTrees.family64.maxint + 1)
+
+        with self.assertRaises((TypeError, OverflowError)):
+            s.insert(BTrees.family64.minint - 1)
+
         self.check_pickling(BTrees.family64)
 
     def check_pickling(self, family):
@@ -529,8 +535,8 @@ class FamilyTest(unittest.TestCase):
         u = pickle.Unpickler(BytesIO(sio.getvalue()))
         f1 = u.load()
         f2, = u.load()
-        self.assertTrue(f1 is family)
-        self.assertTrue(f2 is family)
+        self.assertIs(f1, family)
+        self.assertIs(f2, family)
 
         # Using separate memos for each pickle:
         sio = BytesIO()
@@ -541,5 +547,5 @@ class FamilyTest(unittest.TestCase):
         u = pickle.Unpickler(BytesIO(sio.getvalue()))
         f1 = u.load()
         f2, = u.load()
-        self.assertTrue(f1 is family)
-        self.assertTrue(f2 is family)
+        self.assertIs(f1, family)
+        self.assertIs(f2, family)
